@@ -1,3 +1,6 @@
-VERSION = (2025, 1)
+from __future__ import annotations
+
+
+VERSION = (2025, 1, 1)
 VERSION_STATUS = ""
 VERSION_TEXT = ".".join(str(x) for x in VERSION) + VERSION_STATUS
