@@ -584,9 +584,9 @@ namespace
 
     int ary_flags = 0;
     if (order == NPY_FORTRANORDER)
-      ary_flags |= NPY_FARRAY;
+      ary_flags |= NPY_ARRAY_FARRAY;
     else if (order == NPY_CORDER)
-      ary_flags |= NPY_CARRAY;
+      ary_flags |= NPY_ARRAY_CARRAY;
     else
       throw pycuda::error("numpy_empty", CUDA_ERROR_INVALID_VALUE,
           "unrecognized order specifier");
